Module ir

Module ir 

Structs

ApiEndpointIr
ApiEndpoint node IR, mirroring schema::ApiEndpointNode.
BehaviourIr
Behaviour node IR, mirroring schema::BehaviourNode.
CallbackIr
Callback node IR, mirroring schema::CallbackNode.
ClassIr
Class node IR for languages that map types to Class (CRM-3595).
EdgeIr
A relationship between two nodes in the IR.
ExternalApiIr
ExternalApi node IR, mirroring schema::ExternalApiNode.
FileIr
File node IR, mirroring schema::FileNode.
FunctionIr
Function node IR, mirroring schema::FunctionNode.
ModuleIr
Module node IR, mirroring schema::ModuleNode.
ProjectIr
Serialized, language-agnostic graph representation that can be written to disk and later consumed by a separate “graph loader” runtime.
PropertyIr
Property node IR (C#; CRM-3595).

Enums

EdgeKind
Edge kinds in the IR, aligned with edge::RelType.

Functions

api_endpoint_key
Stable key for an ApiEndpoint node in the IR.
external_api_key
Stable key for an ExternalApi node in the IR.
module_key
Stable key for a Module node in the IR.