pub fn parse_project(
root: &Path,
scan: &ScanOptions,
) -> Result<InMemoryGraph, ProjectError>Expand description
Parse an entire workspace and return a queryable in-memory graph.
pub fn parse_project(
root: &Path,
scan: &ScanOptions,
) -> Result<InMemoryGraph, ProjectError>Parse an entire workspace and return a queryable in-memory graph.