Module python_common_external

Module python_common_external 

Common third-party / optional top-level names (PyPI, Sphinx, etc.). Imports whose first segment is listed here are not logged as unresolved when they do not map to scanned files (same idea as stdlib filtering).

Functions

is_python_common_external_top_level
True if the first component of a dotted import is a known external package name.