Module schema

Module schema 

Modules

props
Common property keys shared across node types.

Structs

ApiEndpointNode
Structured view of the properties we expect on an ApiEndpoint node.
BehaviourNode
Structured view of the properties we expect on a Behaviour node.
CallbackNode
Structured view of the properties we expect on a Callback node.
ExternalApiNode
Structured view of the properties we expect on an ExternalApi node.
FileNode
Structured view of the properties we expect on a File node.
FunctionNode
Structured view of the properties we expect on a Function node.
ModuleNode
Structured view of the properties we expect on a Module node.

Enums

NodeLabel
Labels used for nodes in the Neo4j graph.